@@ -44,7 +44,7 @@ class _SafeFileCache(FileCache):
                 self._logged_warning = True
             return None
 
-    def set(self, key: str, value: bytes) -> None:
+    def set(self, key: str, value: bytes, expires: Optional[Any] = None) -> None:
         try:
             self._set_impl(key, value)
         except Exception as e:  # pragma: no cover
@@ -152,7 +152,7 @@ class PyPIService(VulnerabilityService):
         except requests.HTTPError as http_error:
             if response.status_code == 404:
                 logger.warning(
-                    "Warning: Dependency not found on PyPI and could not be"
+                    "Warning: Dependency not found on PyPI and could not be "
                     f"audited: {spec.canonical_name} ({spec.version})"
                 )
                 return []
